@@ -2,20 +2,24 @@
 These are all the functions that are used when you `cytoplasm build`.
 '''
 
-import os, shutil
+import os
+import shutil
 from cytoplasm import errors, interpreters, configuration
 from cytoplasm.controllers import controllerclass
 
+
 def copy_over(config):
     "Copy the files not beginning with '_' to the site directory"
     interpreter_dictionary = config.interpreters
     # All of the files and directories that don't begin with '_' or '.'
-    to_copy = [file for file in os.listdir(".") if not file.startswith(("_", "."))]
+    to_copy = [file for file in os.listdir(".") if not
+            file.startswith(("_", "."))]
     files = [file for file in to_copy if not os.path.isdir(file)]
     for file in files:
         destination = interpreters.interpreted_filename(file)
         # and pass the origin and destination to interpreters.interpret.
-        interpreters.interpret(file, os.path.join(config.build_dir, destination))
+        interpreters.interpret(file,
+                os.path.join(config.build_dir, destination))
     directories = [file for file in to_copy if os.path.isdir(file)]
     for dir in directories:
         if os.path.exists(os.path.join(config.build_dir, dir)):
@@ -24,8 +28,10 @@ def copy_over(config):
         # copy all the directories that don't start with "." or "_" completely.
         shutil.copytree(dir, os.path.join(config.build_dir, dir))
 
+
 def build(dir="."):
-    # Set the directory in cytoplasm.configuration, so everything gets the same configuration.
+    # Set the directory in cytoplasm.configuration, so everything gets the
+    # same configuration.
     configuration.source_dir = os.path.join(os.getcwd(), dir)
     # Get the configuration file...
     config = configuration.get_config()
@@ -40,8 +46,7 @@ def build(dir="."):
     for controller, arguments in config.controllers:
         # create a controller object of the class returned by controllerclass
         controller_object = controllerclass(controller)(*arguments)
-        # call the controller object 
+        # call the controller object
         controller_object()
     # change back to the old directory.
     os.chdir(oldwd)
-
